@@ -8,7 +8,7 @@ import xgboost as xgb
 from xgboost import cv
 
 
-class adVala:
+class adVal:
 
     def __init__(self, train, test, similarity_ratio ,target, id):
         self.train = train
@@ -55,6 +55,6 @@ class adVala:
         sc = 100 - ((score - 0.5) * 200 )
         sr = self.similarity_ratio
         if sc >= sr:
-            print("Train and test data are similar, Similarity Ratio: ½{:.4}".format(sc))
+            print("Train and test data are similar, Similarity Ratio: %{:.4}".format(sc))
         else: 
-            print("Train and test data are not similar, Similarity Ratio: ½{:.4}".format(sc))
+            print("Train and test data are not similar, Similarity Ratio: %{:.4}".format(sc))
